@@ -11,7 +11,7 @@
 #' records only in master and checklist and statistics about the
 #' records including Jaccard index
 #' @examples
-#' \dontrun{
+#' \donttest{
 #'master <- data.frame("canonical" = c("Abrothrix longipilis",
 #'                                     "Acodon hirtus",
 #'                                     "Akodon longipilis apta",
@@ -59,11 +59,13 @@ match_lists <- function(master,checklist,masterfld,checklistfld){
   retval$stat$matchrec <- nrow(retval$matchlist)
   retval$stat$onlymasterrec <- nrow(retval$onlymaster)
   retval$stat$onlychecklistrec <- nrow(retval$onlychecklist)
-  retval$stat$mastertaxa <- nrow(master[which(master$accid==0),])
-  retval$stat$checktaxa <- nrow(checklist[which(checklist$accid==0),])
-  retval$stat$matchtaxa <- nrow(retval$matchlist[which(retval$matchlist$accid==0),])
-  retval$stat$onlymastertaxa <- nrow(retval$onlymaster[which(retval$onlymaster$accid==0),])
-  retval$stat$onlychecklisttaxa <- nrow(retval$onlychecklist[which(retval$onlychecklist$accid==0),])
+  if("accid" %in% names(master) & "accid" %in% names(checklist)){
+    retval$stat$mastertaxa <- nrow(master[which(master$accid==0),])
+    retval$stat$checktaxa <- nrow(checklist[which(checklist$accid==0),])
+    retval$stat$matchtaxa <- nrow(retval$matchlist[which(retval$matchlist$accid==0),])
+    retval$stat$onlymastertaxa <- nrow(retval$onlymaster[which(retval$onlymaster$accid==0),])
+    retval$stat$onlychecklisttaxa <- nrow(retval$onlychecklist[which(retval$onlychecklist$accid==0),])
+  }
   retval$stat$jaccard <- nrow(retval$matchlist) /
     ( nrow(retval$matchlist) +
         nrow(retval$onlymaster) +
